summaryrefslogtreecommitdiffstats
path: root/Lib/test/test_logging.py
diff options
context:
space:
mode:
Diffstat (limited to 'Lib/test/test_logging.py')
-rw-r--r--Lib/test/test_logging.py4
1 files changed, 2 insertions, 2 deletions
diff --git a/Lib/test/test_logging.py b/Lib/test/test_logging.py
index 36ea072..a91cfd4 100644
--- a/Lib/test/test_logging.py
+++ b/Lib/test/test_logging.py
@@ -1273,7 +1273,7 @@ class ConfigFileTest(BaseTest):
datefmt=
"""
# config7 adds a compiler logger.
config7 = """
[loggers]
keys=root,parser,compiler
@@ -1304,7 +1304,7 @@ class ConfigFileTest(BaseTest):
class=StreamHandler
level=NOTSET
formatter=form1
- args=(sys.stdout,)
+ kwargs={'stream': sys.stdout,}
[formatter_form1]
format=%(levelname)s ++ %(message)s
@@ -1273,7 +1273,7 @@ class ConfigFileTest(BaseTest):
datefmt=
"""
- # config7 adds a compiler logger.
+ # config7 adds a compiler logger, and uses kwargs instead of args.
config7 = """
[loggers]